pyhsm.exception

Package pyhsm :: Module exception |
[frames] | no frames]

# Module exception

common exceptions for the pyhsm package

Classes
| YHSM_Error Base class for YHSM exceptions in this package.
| YHSM_WrongInputSize Exception raised for errors in the size of an argument to some function.
| YHSM_InputTooShort Exception raised for too short input to some function.
| YHSM_InputTooLong Exception raised for too long input to some function.
| YHSM_WrongInputType Exception raised for errors in the type of an argument to some function.
| YHSM_CommandFailed Exception raised when a command sent to the YubiHSM returned an error.